==> radiance-ui-2.0.2.tgz: package/lib/shared-components/immersiveModal/index.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import PropTypes from 'prop-types';
import React from 'react';
import ReactDOM from 'react-dom';
import KEYCODES from '../../constants/keycodes';
import keyPressMatch from '../../utils/keyPressMatch';
import OffClickWrapper from '../offClickWrapper';
import CloseIcon from '../../svgs/icons/close-icon.svg';
import { ModalContainer, Overlay, CloseIconContainer, CopyContainer, Title, Body, Footer } from './style';

var ImmersiveModal =
/*#__PURE__*/
function (_React$Component) {
  _inherits(ImmersiveModal, _React$Component);

  function ImmersiveModal(props) {
    var _this;

    _classCallCheck(this, ImmersiveModal);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(ImmersiveModal).call(this, props));

    _this.handleEscapeKey = function (event) {
      if (keyPressMatch(event, KEYCODES.escape)) {
        _this.closeModal();
      }
    };

    _this.closeModal = function () {
      var _this$props = _this.props,
          canBeClosed = _this$props.canBeClosed,
          onClose = _this$props.onClose;

      if (canBeClosed) {
        onClose();
      }
    };

    _this.htmlNode = document.querySelector('html');
    _this.domNode = document.querySelector('#reactPortalSection') || document.body;
    return _this;
  }

  _createClass(ImmersiveModal, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.htmlNode.classList.add('no-scroll');
      document.getElementsByTagName('body')[0].addEventListener('keydown', this.handleEscapeKey);
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.htmlNode.classList.remove('no-scroll');
      document.getElementsByTagName('body')[0].removeEventListener('keydown', this.handleEscapeKey);
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          canBeClosed = _this$props2.canBeClosed,
          onClose = _this$props2.onClose,
          header = _this$props2.header;
      return ReactDOM.createPortal(React.createElement(Overlay, null, React.createElement(ModalContainer, null, React.createElement(OffClickWrapper, {
        onOffClick: this.closeModal
      }, canBeClosed && React.createElement(CloseIconContainer, {
        onClick: onClose
      }, React.createElement(CloseIcon, null)), header, React.createElement(CopyContainer, null, children)))), this.domNode);
    }
  }]);

  return ImmersiveModal;
}(React.Component);

ImmersiveModal.propTypes = {
  children: PropTypes.node.isRequired,
  canBeClosed: PropTypes.bool,
  onClose: PropTypes.func,
  header: PropTypes.node
};
ImmersiveModal.defaultProps = {
  canBeClosed: true,
  onClose: function onClose() {}
};
ImmersiveModal.Title = Title;
ImmersiveModal.Body = Body;
ImmersiveModal.Footer = Footer;
export default ImmersiveModal;

==> radiance-ui-2.0.5.tgz: package/lib/shared-components/immersiveModal/index.js <==
import { jsx as ___EmotionJSX } from "@emotion/core";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import PropTypes from 'prop-types';
import React from 'react';
import ReactDOM from 'react-dom';
import KEYCODES from '../../constants/keycodes';
import keyPressMatch from '../../utils/keyPressMatch';
import OffClickWrapper from '../offClickWrapper';
import CloseIcon from '../../svgs/icons/close-icon.svg';
import { ModalContainer, Overlay, CloseIconContainer, CopyContainer, Title, Body, Footer } from './style';

var ImmersiveModal =
/*#__PURE__*/
function (_React$Component) {
  _inherits(ImmersiveModal, _React$Component);

  function ImmersiveModal(props) {
    var _this;

    _classCallCheck(this, ImmersiveModal);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(ImmersiveModal).call(this, props));

    _this.handleEscapeKey = function (event) {
      if (keyPressMatch(event, KEYCODES.escape)) {
        _this.closeModal();
      }
    };

    _this.closeModal = function () {
      var _this$props = _this.props,
          canBeClosed = _this$props.canBeClosed,
          onClose = _this$props.onClose;

      if (canBeClosed) {
        onClose();
      }
    };

    _this.htmlNode = document.querySelector('html');
    _this.domNode = document.querySelector('#reactPortalSection') || document.body;
    return _this;
  }

  _createClass(ImmersiveModal, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.htmlNode.classList.add('no-scroll');
      document.getElementsByTagName('body')[0].addEventListener('keydown', this.handleEscapeKey);
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.htmlNode.classList.remove('no-scroll');
      document.getElementsByTagName('body')[0].removeEventListener('keydown', this.handleEscapeKey);
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          canBeClosed = _this$props2.canBeClosed,
          onClose = _this$props2.onClose,
          header = _this$props2.header;
      return ReactDOM.createPortal(___EmotionJSX(Overlay, null, ___EmotionJSX(ModalContainer, null, ___EmotionJSX(OffClickWrapper, {
        onOffClick: this.closeModal
      }, canBeClosed && ___EmotionJSX(CloseIconContainer, {
        onClick: onClose
      }, ___EmotionJSX(CloseIcon, null)), header, ___EmotionJSX(CopyContainer, null, children)))), this.domNode);
    }
  }]);

  return ImmersiveModal;
}(React.Component);

ImmersiveModal.propTypes = {
  children: PropTypes.node.isRequired,
  canBeClosed: PropTypes.bool,
  onClose: PropTypes.func,
  header: PropTypes.node
};
ImmersiveModal.defaultProps = {
  canBeClosed: true,
  onClose: function onClose() {}
};
ImmersiveModal.Title = Title;
ImmersiveModal.Body = Body;
ImmersiveModal.Footer = Footer;
export default ImmersiveModal;
